<?php

namespace FiloBlu\GcpLogging\Observer;

use FiloBlu\GcpLogging\Helper\Data;
use Google\Cloud\Logging\LoggingClient;
use Magento\Backend\Model\Auth\Session;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Message\ManagerInterface;

class CheckConfigData implements ObserverInterface
{
    /**
     * @var Data
     */
    protected $helper;

    /**
     * @var Session
     */
    protected $authSession;

    /**
     * @var ManagerInterface
     */
    protected $messageManager;

    public function __construct(
        Data             $helper,
        Session          $authSession,
        ManagerInterface $messageManager
    )
    {
        $this->helper = $helper;
        $this->authSession = $authSession;
        $this->messageManager = $messageManager;
    }

    /**
     * Observer to check the gcp configuration set to BE.
     * It works for Magento 2.3 and higher, due to lack of event dispatch on the lower versions.
     *
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        $observer = $observer->getEvent();
        if ($observer->getData('configData')['section'] == 'filoblu_gcp_logging') {
            $type = $this->helper->getGcpLoggingType();
            if ($type == Data::LOG_TYPE_GCP) {

                try {
                    $client = new LoggingClient($this->helper->getLoggingClientConfiguration());
                    $client->psrLogger($this->helper->getLogFileName(), ['labels' => ['context' => 'Filoblu_Gcp_Logging']])
                        ->log('INFO', 'Save Gcp Logging Config', ['user' => $this->authSession->getUser()->getUserName()]);

                } catch (\Exception $e) {
                    $this->messageManager->addWarningMessage('GCP configuration error: ' . $e->getMessage());
                }
            }
        }
    }
}
